@@ -25,6 +25,7 @@ from crowdin_api.api_resources.projects.types import (
     XliffStringsExporterSettings,
     QAChecksIgnorableCategories
 )
+from crowdin_api.sorting import Sorting
 
 
 class ProjectsResource(BaseResource):
@@ -47,6 +48,7 @@ class ProjectsResource(BaseResource):
 
     def list_projects(
         self,
+        orderBy: Optional[Sorting] = None,
         page: Optional[int] = None,
         offset: Optional[int] = None,
         limit: Optional[int] = None,
@@ -61,7 +63,7 @@ class ProjectsResource(BaseResource):
         https://developer.crowdin.com/api/v2/#operation/api.projects.getMany
         """
 
-        params = {"userId": userId, "hasManagerAccess": hasManagerAccess, "groupId": groupId}
+        params = {"orderBy": orderBy, "userId": userId, "hasManagerAccess": hasManagerAccess, "groupId": groupId}
         params.update(self.get_page_params(page=page, offset=offset, limit=limit))
 
         return self._get_entire_data(method="get", path=self.get_projects_path(), params=params)
