@@ -160,6 +160,76 @@ class BaseReportsResource(BaseResource):
             },
         )
 
+    def generate_pre_translate_accuracy_general_report(
+        self,
+        projectId: Optional[int] = None,
+        unit: Optional[Unit] = None,
+        format: Optional[Format] = None,
+        postEditingCategories: Optional[Iterable[str]] = None,
+        languageId: Optional[str] = None,
+        dateFrom: Optional[datetime] = None,
+        dateTo: Optional[datetime] = None,
+    ):
+        """
+        Generate Report.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
+
+        Link to documentation for enterprise:
+        https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.post
+        """
+
+        projectId = projectId or self.get_project_id()
+
+        return self.generate_report(
+            projectId=projectId,
+            request_data={
+                "name": "pre-translate-accuracy",
+                "schema": {
+                    "unit": unit,
+                    "format": format,
+                    "postEditingCategories": postEditingCategories,
+                    "languageId": languageId,
+                    "dateFrom": dateFrom,
+                    "dateTo": dateTo,
+                },
+            },
+        )
+
+    def generate_pre_translate_accuracy_by_task_report(
+        self,
+        projectId: Optional[int] = None,
+        unit: Optional[Unit] = None,
+        format: Optional[Format] = None,
+        postEditingCategories: Optional[Iterable[str]] = None,
+        taskId: Optional[int] = None,
+    ):
+        """
+        Generate Report.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
+
+        Link to documentation for enterprise:
+        https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.post
+        """
+
+        projectId = projectId or self.get_project_id()
+
+        return self.generate_report(
+            projectId=projectId,
+            request_data={
+                "name": "pre-translate-accuracy",
+                "schema": {
+                    "unit": unit,
+                    "format": format,
+                    "postEditingCategories": postEditingCategories,
+                    "taskId": taskId,
+                },
+            },
+        )
+
     def generate_costs_estimation_post_editing_general_report(
         self,
         base_rates: BaseRates,
@@ -1254,3 +1324,128 @@ class EnterpriseReportsResource(BaseReportsResource, BaseReportSettingsTemplates
                 },
             },
         )
+
+
+class UserReportSettingsTemplatesResource(BaseReportSettingsTemplatesResource):
+    """
+    Resource for User Report Settings Templates API.
+
+    Supporting the endpoints for managing user report settings templates.
+    Link to documentation:
+    https://developer.crowdin.com/api/v2/#tag/User-Report-Settings-Templates
+    """
+
+    def get_user_report_settings_templates_path(
+        self,
+        userId: int,
+        reportSettingsTemplateId: Optional[int] = None
+    ):
+        if reportSettingsTemplateId is not None:
+            return f"users/{userId}/reports/settings-templates/{reportSettingsTemplateId}"
+
+        return f"users/{userId}/reports/settings-templates"
+
+    def list_user_report_settings_template(
+        self,
+        userId: int,
+        offset: Optional[int] = None,
+        limit: Optional[int] = None
+    ):
+        """
+        List User Report Settings Templates.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.users.reports.settings-templates.getMany
+        """
+        return self._get_entire_data(
+            method="get",
+            path=self.get_user_report_settings_templates_path(userId=userId),
+            params=self.get_page_params(offset=offset, limit=limit),
+        )
+
+    def add_user_report_settings_template(
+        self,
+        userId: int,
+        name: str,
+        currency: Currency,
+        unit: Unit,
+        config: Config,
+    ):
+        """
+        Add User Report Settings Template.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.users.reports.settings-templates.post
+        """
+        return self.requester.request(
+            method="post",
+            path=self.get_user_report_settings_templates_path(
+                userId=userId,
+            ),
+            request_data={
+                "name": name,
+                "currency": currency,
+                "unit": unit,
+                "mode": "simple",
+                "config": config,
+            }
+        )
+
+    def get_user_report_settings_template(
+        self,
+        userId: int,
+        reportSettingsTemplateId: int,
+    ):
+        """
+        Get User Report Settings Template.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.users.reports.settings-templates.get
+        """
+        return self.requester.request(
+            method="get",
+            path=self.get_user_report_settings_templates_path(
+                userId=userId,
+                reportSettingsTemplateId=reportSettingsTemplateId
+            ),
+        )
+
+    def edit_user_report_settings_template(
+        self,
+        userId: int,
+        reportSettingsTemplateId: int,
+        data: Iterable[ReportSettingsTemplatesPatchRequest],
+    ):
+        """
+        Edit User Report Settings Template.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.users.reports.settings-templates.patch
+        """
+        return self.requester.request(
+            method="patch",
+            path=self.get_user_report_settings_templates_path(
+                userId=userId,
+                reportSettingsTemplateId=reportSettingsTemplateId
+            ),
+            request_data=data,
+        )
+
+    def delete_user_report_settings_template(
+        self,
+        userId: int,
+        reportSettingsTemplateId: int,
+    ):
+        """
+        Delete User Report Settings Template.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.users.reports.settings-templates.delete
+        """
+        return self.requester.request(
+            method="delete",
+            path=self.get_user_report_settings_templates_path(
+                userId=userId,
+                reportSettingsTemplateId=reportSettingsTemplateId
+            ),
+        )
